types_python_dateutil: Typing stubs for python-dateutil
=======================================================

Description
-----------

Typing stubs for python-dateutil

License
-------

Apache-2.0 license

Upstream Contact
----------------

https://pypi.org/project/types-python-dateutil/

